package com.ruoyi.report.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.report.mapper.RecordShiftamountDayMapper;
import com.ruoyi.report.domain.RecordShiftamountDay;
import com.ruoyi.report.service.IRecordShiftamountDayService;
import com.ruoyi.common.core.text.Convert;

/**
 * 班次产量日报Service业务层处理
 * 
 * @author CaesarBao
 * @date 2020-11-03
 */
@Service
public class RecordShiftamountDayServiceImpl implements IRecordShiftamountDayService 
{
    @Autowired
    private RecordShiftamountDayMapper recordShiftamountDayMapper;

    /**
     * 查询班次产量日报
     * 
     * @param objid 班次产量日报ID
     * @return 班次产量日报
     */
    @Override
    public RecordShiftamountDay selectRecordShiftamountDayById(Long objid)
    {
        return recordShiftamountDayMapper.selectRecordShiftamountDayById(objid);
    }

    /**
     * 查询班次产量日报列表
     * 
     * @param recordShiftamountDay 班次产量日报
     * @return 班次产量日报
     */
    @Override
    public List<RecordShiftamountDay> selectRecordShiftamountDayList(RecordShiftamountDay recordShiftamountDay)
    {
        return recordShiftamountDayMapper.selectRecordShiftamountDayList(recordShiftamountDay);
    }

    /**
     * 新增班次产量日报
     * 
     * @param recordShiftamountDay 班次产量日报
     * @return 结果
     */
    @Override
    public int insertRecordShiftamountDay(RecordShiftamountDay recordShiftamountDay)
    {
        return recordShiftamountDayMapper.insertRecordShiftamountDay(recordShiftamountDay);
    }

    /**
     * 修改班次产量日报
     * 
     * @param recordShiftamountDay 班次产量日报
     * @return 结果
     */
    @Override
    public int updateRecordShiftamountDay(RecordShiftamountDay recordShiftamountDay)
    {
        return recordShiftamountDayMapper.updateRecordShiftamountDay(recordShiftamountDay);
    }

    /**
     * 删除班次产量日报对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteRecordShiftamountDayByIds(String ids)
    {
        return recordShiftamountDayMapper.deleteRecordShiftamountDayByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除班次产量日报信息
     * 
     * @param objid 班次产量日报ID
     * @return 结果
     */
    @Override
    public int deleteRecordShiftamountDayById(Long objid)
    {
        return recordShiftamountDayMapper.deleteRecordShiftamountDayById(objid);
    }
}
